# LLVMPY Meow!

llvmpym is a python library that provides LLVM binding. It bases on the LLVM C API.  

This project is still in a very early stage  


Target LLVM version: `18.1.8`  

## Documentation

[link](https://ziqi-yang.github.io/llvmpym/)  

Past versions of document can be downloaded on the Release Page.

## Related Projects

[lliv](https://codeberg.org/meow_king/lliv): An interactive LLVM IR viewer based on llvmpym.

